==> blesta-5.10.2.zip: blesta/language/pl_pl/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Klient zapomniał nazwy użytkownika';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Resetowanie hasła klienta';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Administrator Resetuj moje hasło';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Logowanie klienta';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Logowanie administratora';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'Klucz współdzielony reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha Site Key';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Wewnętrzna Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Brak';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Włączone formularze';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Dostawca Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Weryfikacja człowieka';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Wyszukiwanie pakietów';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Wyszukiwanie usług';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Wyszukiwanie transakcji';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Wyszukiwanie notowań';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Wyszukiwanie faktur';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Wyszukiwanie klientów';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Inteligentne wyszukiwanie';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Przedstawienie klientom opcji włączenia/wyłączenia marketingu e-mailowego.';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Definicja języka użytkowania';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ustawienia > Firma > Ogólne > Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Definicja języka użytkowania';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ustawienia > Firma > Ogólne > Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Pole to należy zaznaczyć tylko w przypadku dodania definicji języka dla tego typu kontaktu w pliku języka niestandardowego.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Nie ma typów kontaktów.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Usunięcie tego typu kontaktu spowoduje, że wszystkie kontakty przypisane do tego typu zostaną umieszczone w domyślnym typie "Billing". Czy na pewno chcesz usunąć ten typ kontaktu?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Usuń';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Edytuj';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Nie';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Tak';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Opcje';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Używa języka Definicja';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Rodzaje kontaktów';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ustawienia > Firma > Ogólne > Typy kontaktów';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Zaktualizuj hasło';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Zapisałem to hasło w bezpiecznym miejscu';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Potwierdź hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Nowe hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Aktualne hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Szyfrowanie';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'OSTRZEŻENIE: Hasło zostało ustawione. Wymagane jest ręczne grupowanie płatności przy użyciu hasła. Zmiana hasła na puste usunie ten wymóg.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'OSTRZEŻENIE: Ustawienie hasła uniemożliwi automatyczne przetwarzanie lokalnie przechowywanych kont płatniczych. Konieczne będzie ręczne grupowanie płatności poprzez wprowadzenie hasła. Więcej informacji na temat tej funkcji można znaleźć w instrukcji obsługi.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ustawienia > Firma > Ogólne > Szyfrowanie';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Czy na pewno chcesz odinstalować język %1$s? Ten język zostanie odinstalowany, a wszystkie szablony wiadomości e-mail w tym języku zostaną trwale usunięte.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Czy na pewno chcesz zainstalować język %1$s?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Odinstaluj';
$lang['AdminCompanyGeneral.international.option_install'] = 'Instalacja';
$lang['AdminCompanyGeneral.international.text_options'] = 'Opcje';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Język';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internacjonalizacja';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ustawienia > Firma > Ogólne > Internacjonalizacja';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Pod adresem translate.blesta.com dostępny jest crowdsourcingowy projekt tłumaczeniowy. Możesz tam współtworzyć i pobierać tłumaczenia językowe. Aby zainstalować, rozpakuj zawartość pliku do katalogu instalacyjnego Blesta. Następnie odśwież tę stronę i kliknij łącze Zainstaluj.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Domyślny kraj';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Format daty i godziny';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Format daty';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Strefa czasowa';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Poniedziałek';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Niedziela';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Dzień rozpoczęcia kalendarza';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Klient może ustawić Język';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Domyślny język';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Lokalizacja';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ustawienia > Firma > Ogólne > Lokalizacja';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Jest to captcha używana domyślnie, wewnętrzna captcha wymaga rozszerzenia GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Jest to kraj wybrany domyślnie w odpowiednich formularzach.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Ustawia format daty i godziny. Format ten jest używany podczas wyświetlania daty i godziny. Dostępne opcje można znaleźć w podręczniku php.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Ustawia format daty. Format ten jest używany podczas wyświetlania daty. Dostępne opcje można znaleźć w podręczniku php.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Jest to systemowa strefa czasowa, do której zostaną sformatowane konwersje daty i godziny.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Ustawienie tygodniowego dnia rozpoczęcia kalendarza.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Po zaznaczeniu tej opcji klienci mogą wybrać własny język spośród dostępnych w systemie.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Domyślny język używany przez system. Aby dodać więcej języków, zobacz Ustawienia internacjonalizacji.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Ustawienia weryfikacji użytkownika zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Ustawienia Smart Search zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Ustawienia marketingowe zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Język %1$s został pomyślnie odinstalowany.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Język %1$s został pomyślnie zainstalowany.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Kontakt typu "%1$s" został pomyślnie usunięty.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Kontakt typu "%1$s" został pomyślnie zaktualizowany.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Kontakt typu "%1$s" został pomyślnie dodany.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Ustawienia szyfrowania zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Ustawienia lokalizacji zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Rozszerzenie GD jest wymagane do generowania wewnętrznego captcha.';

==> blesta-5.11.4.zip: blesta/language/pl_pl/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Klient zapomniał nazwy użytkownika';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Resetowanie hasła klienta';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Administrator Resetuj moje hasło';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Logowanie klienta';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Logowanie administratora';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'Klucz współdzielony reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha Site Key';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Wewnętrzna Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Brak';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Włączone formularze';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Dostawca Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Weryfikacja człowieka';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Wyszukiwanie pakietów';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Wyszukiwanie usług';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Wyszukiwanie transakcji';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Wyszukiwanie notowań';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Wyszukiwanie faktur';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Wyszukiwanie klientów';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Inteligentne wyszukiwanie';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Przedstawienie klientom opcji włączenia/wyłączenia marketingu e-mailowego.';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Definicja języka użytkowania';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ustawienia > Firma > Ogólne > Edytuj typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Definicja języka użytkowania';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ustawienia > Firma > Ogólne > Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Pole to należy zaznaczyć tylko w przypadku dodania definicji języka dla tego typu kontaktu w pliku języka niestandardowego.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Nie ma typów kontaktów.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Usunięcie tego typu kontaktu spowoduje, że wszystkie kontakty przypisane do tego typu zostaną umieszczone w domyślnym typie "Billing". Czy na pewno chcesz usunąć ten typ kontaktu?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Usuń';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Edytuj';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Nie';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Tak';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Opcje';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Używa języka Definicja';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Nazwa';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Rodzaje kontaktów';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Utwórz typ kontaktu';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ustawienia > Firma > Ogólne > Typy kontaktów';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Zaktualizuj hasło';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Zapisałem to hasło w bezpiecznym miejscu';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Potwierdź hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Nowe hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Aktualne hasło klucza prywatnego';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Szyfrowanie';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'OSTRZEŻENIE: Hasło zostało ustawione. Wymagane jest ręczne grupowanie płatności przy użyciu hasła. Zmiana hasła na puste usunie ten wymóg.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'OSTRZEŻENIE: Ustawienie hasła uniemożliwi automatyczne przetwarzanie lokalnie przechowywanych kont płatniczych. Konieczne będzie ręczne grupowanie płatności poprzez wprowadzenie hasła. Więcej informacji na temat tej funkcji można znaleźć w instrukcji obsługi.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ustawienia > Firma > Ogólne > Szyfrowanie';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Czy na pewno chcesz odinstalować język %1$s? Ten język zostanie odinstalowany, a wszystkie szablony wiadomości e-mail w tym języku zostaną trwale usunięte.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Czy na pewno chcesz zainstalować język %1$s?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Odinstaluj';
$lang['AdminCompanyGeneral.international.option_install'] = 'Instalacja';
$lang['AdminCompanyGeneral.international.text_options'] = 'Opcje';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Język';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internacjonalizacja';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ustawienia > Firma > Ogólne > Internacjonalizacja';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Pod adresem translate.blesta.com dostępny jest crowdsourcingowy projekt tłumaczeniowy. Możesz tam współtworzyć i pobierać tłumaczenia językowe. Aby zainstalować, rozpakuj zawartość pliku do katalogu instalacyjnego Blesta. Następnie odśwież tę stronę i kliknij łącze Zainstaluj.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ustawienia aktualizacji';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Domyślny kraj';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Format daty i godziny';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Format daty';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Strefa czasowa';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Poniedziałek';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Niedziela';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Dzień rozpoczęcia kalendarza';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Klient może ustawić Język';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Domyślny język';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Lokalizacja';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ustawienia > Firma > Ogólne > Lokalizacja';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Jest to captcha używana domyślnie, wewnętrzna captcha wymaga rozszerzenia GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Jest to kraj wybrany domyślnie w odpowiednich formularzach.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Ustawia format daty i godziny. Format ten jest używany podczas wyświetlania daty i godziny. Dostępne opcje można znaleźć w podręczniku php.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Ustawia format daty. Format ten jest używany podczas wyświetlania daty. Dostępne opcje można znaleźć w podręczniku php.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Jest to systemowa strefa czasowa, do której zostaną sformatowane konwersje daty i godziny.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Ustawienie tygodniowego dnia rozpoczęcia kalendarza.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Po zaznaczeniu tej opcji klienci mogą wybrać własny język spośród dostępnych w systemie.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Domyślny język używany przez system. Aby dodać więcej języków, zobacz Ustawienia internacjonalizacji.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Ustawienia weryfikacji użytkownika zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Ustawienia Smart Search zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Ustawienia marketingowe zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Język %1$s został pomyślnie odinstalowany.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Język %1$s został pomyślnie zainstalowany. Pamiętaj, aby zaktualizować wiadomości e-mail, pakiety i grupy pakietów o zawartość dla nowego języka.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Kontakt typu "%1$s" został pomyślnie usunięty.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Kontakt typu "%1$s" został pomyślnie zaktualizowany.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Kontakt typu "%1$s" został pomyślnie dodany.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Ustawienia szyfrowania zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Ustawienia lokalizacji zostały pomyślnie zaktualizowane.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Rozszerzenie GD jest wymagane do generowania wewnętrznego captcha.';
